@@ -17,10 +17,10 @@ class Admin(object):
             response = requests.get(
                 url=f"https://api.ccauth.app/api/v3/getkey?key={self.apikey}",
                 headers={
-                    "data": {
+                    "data": json.dumps({
                         "type": license_type,
                         "time": license_length
-                    },
+                    }),
                     "userType": user_type,
                     "aid": self.aid,
                     "pass": self.password,
